@@ -1,43 +1,16 @@
 use std::time::Instant;
 
 use rand::{
-    distributions::{
-        Distribution,
-        Standard,
-    },
+    distributions::{Distribution, Standard},
     prelude::*,
 };
 
-use glutin::event::{
-    DeviceEvent,
-    ElementState,
-    Event,
-    KeyboardInput,
-    MouseButton,
-    VirtualKeyCode,
-    WindowEvent,
-};
-use glutin::event_loop::{
-    ControlFlow,
-    EventLoop,
-};
-use glutin::window::{
-    Window,
-    WindowBuilder,
-};
+use glutin::event::{DeviceEvent, ElementState, Event, KeyboardInput, MouseButton, VirtualKeyCode, WindowEvent};
+use glutin::event_loop::{ControlFlow, EventLoop};
+use glutin::window::{Window, WindowBuilder};
 use glutin::ContextBuilder;
 
-use femtovg::{
-    renderer::OpenGl,
-    Align,
-    Baseline,
-    Color,
-    FontId,
-    ImageFlags,
-    ImageId,
-    Paint,
-    Path,
-};
+use femtovg::{renderer::OpenGl, Align, Baseline, Color, FontId, ImageFlags, ImageId, Paint, Path};
 
 type Canvas = femtovg::Canvas<OpenGl>;
 type Point = euclid::default::Point2D<f32>;
@@ -1278,7 +1251,7 @@ fn main() {
     let windowed_context = ContextBuilder::new().build_windowed(wb, &el).unwrap();
     let windowed_context = unsafe { windowed_context.make_current().unwrap() };
 
-    let renderer = OpenGl::new(|s| windowed_context.get_proc_address(s) as *const _).expect("Cannot create renderer");
+    let renderer = OpenGl::new_from_glutin_context(&windowed_context).expect("Cannot create renderer");
     let mut canvas = Canvas::new(renderer).expect("Cannot create canvas");
     canvas.set_size(
         window_size.width as u32,
