@@ -3,18 +3,8 @@ use std::f32::consts::PI;
 use resource::resource;
 
 use instant::Instant;
-use winit::event::{
-    ElementState,
-    Event,
-    KeyboardInput,
-    MouseButton,
-    VirtualKeyCode,
-    WindowEvent,
-};
-use winit::event_loop::{
-    ControlFlow,
-    EventLoop,
-};
+use winit::event::{ElementState, Event, KeyboardInput, MouseButton, VirtualKeyCode, WindowEvent};
+use winit::event_loop::{ControlFlow, EventLoop};
 use winit::window::WindowBuilder;
 //use glutin::{GlRequest, Api};
 
@@ -60,7 +50,7 @@ fn main() {
         use glutin::ContextBuilder;
 
         let wb = WindowBuilder::new()
-            .with_inner_size(winit::dpi::PhysicalSize::new(1000, 600))
+            .with_inner_size(winit::dpi::PhysicalSize::<f32>::new(1000., 600.))
             .with_title("femtovg demo");
 
         //let windowed_context = ContextBuilder::new().with_gl(GlRequest::Specific(Api::OpenGlEs, (2, 0))).with_vsync(false).build_windowed(wb, &el).unwrap();
@@ -68,8 +58,7 @@ fn main() {
         let windowed_context = ContextBuilder::new().with_vsync(false).build_windowed(wb, &el).unwrap();
         let windowed_context = unsafe { windowed_context.make_current().unwrap() };
 
-        let renderer =
-            OpenGl::new(|s| windowed_context.get_proc_address(s) as *const _).expect("Cannot create renderer");
+        let renderer = OpenGl::new_from_glutin_context(&windowed_context).expect("Cannot create renderer");
 
         (renderer, windowed_context)
     };
@@ -254,12 +243,21 @@ fn main() {
                 let width = size.width as f32;
 
                 let pt = canvas.transform().inversed().transform_point(mousex, mousey);
-                let mousex = pt.0;
-                let mousey = pt.1;
+                let rel_mousex = pt.0;
+                let rel_mousey = pt.1;
 
                 draw_graph(&mut canvas, 0.0, height / 2.0, width, height / 2.0, t);
 
-                draw_eyes(&mut canvas, width - 250.0, 50.0, 150.0, 100.0, mousex, mousey, t);
+                draw_eyes(
+                    &mut canvas,
+                    width - 250.0,
+                    50.0,
+                    150.0,
+                    100.0,
+                    rel_mousex,
+                    rel_mousey,
+                    t,
+                );
 
                 draw_paragraph(
                     &mut canvas,
@@ -268,8 +266,8 @@ fn main() {
                     50.0,
                     150.0,
                     100.0,
-                    mousex,
-                    mousey,
+                    rel_mousex,
+                    rel_mousey,
                 );
 
                 draw_colorwheel(&mut canvas, width - 300.0, height - 350.0, 250.0, 250.0, t);
