@@ -2,16 +2,7 @@
 // so that they are easier to find when autocompleting
 
 use crate::geometry::Transform2D;
-use crate::{
-    Align,
-    Baseline,
-    Color,
-    FillRule,
-    FontId,
-    ImageId,
-    LineCap,
-    LineJoin,
-};
+use crate::{Align, Baseline, Color, FillRule, FontId, ImageId, LineCap, LineJoin};
 
 #[derive(Copy, Clone, Debug, PartialEq, PartialOrd, Default)]
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
@@ -500,6 +491,12 @@ impl Paint {
         self.flavor = PaintFlavor::Color(color);
     }
 
+    /// Returns the paint with a new solid color set to the specified value.
+    pub fn with_color(mut self, color: Color) -> Self {
+        self.set_color(color);
+        self
+    }
+
     pub(crate) fn glyph_texture(&self) -> GlyphTexture {
         self.glyph_texture
     }
@@ -522,6 +519,12 @@ impl Paint {
         self.shape_anti_alias = value;
     }
 
+    /// Returns the paint with anti alias set to the specified value.
+    pub fn with_anti_alias(mut self, value: bool) -> Self {
+        self.set_anti_alias(value);
+        self
+    }
+
     /// True if this paint uses higher quality stencil strokes.
     pub fn stencil_strokes(&self) -> bool {
         self.stencil_strokes
@@ -532,6 +535,12 @@ impl Paint {
         self.stencil_strokes = value;
     }
 
+    /// Returns the paint with stencil strokes set to the specified value.
+    pub fn with_stencil_strokes(mut self, value: bool) -> Self {
+        self.set_stencil_strokes(value);
+        self
+    }
+
     /// Returns the current line width.
     pub fn line_width(&self) -> f32 {
         self.line_width
@@ -542,6 +551,12 @@ impl Paint {
         self.line_width = width;
     }
 
+    /// Returns the paint with line width set to the specified value.
+    pub fn with_line_width(mut self, width: f32) -> Self {
+        self.set_line_width(width);
+        self
+    }
+
     /// Getter for the miter limit
     pub fn miter_limit(&self) -> f32 {
         self.miter_limit
@@ -554,6 +569,12 @@ impl Paint {
         self.miter_limit = limit;
     }
 
+    /// Returns the paint with the miter limit set to the specified value.
+    pub fn with_miter_limit(mut self, limit: f32) -> Self {
+        self.set_miter_limit(limit);
+        self
+    }
+
     /// Returns the current start line cap for this paint.
     pub fn line_cap_start(&self) -> LineCap {
         self.line_cap_start
@@ -572,6 +593,12 @@ impl Paint {
         self.line_cap_end = cap;
     }
 
+    /// Returns the paint with line cap set to the specified value.
+    pub fn with_line_cap(mut self, cap: LineCap) -> Self {
+        self.set_line_cap(cap);
+        self
+    }
+
     /// Sets how the beggining cap of the line is drawn
     ///
     /// By default it's set to LineCap::Butt
@@ -579,6 +606,12 @@ impl Paint {
         self.line_cap_start = cap;
     }
 
+    /// Returns the paint with the beginning cap of the line set to the specified value.
+    pub fn with_line_cap_start(mut self, cap: LineCap) -> Self {
+        self.set_line_cap_start(cap);
+        self
+    }
+
     /// Sets how the end cap of the line is drawn
     ///
     /// By default it's set to LineCap::Butt
@@ -586,6 +619,12 @@ impl Paint {
         self.line_cap_end = cap;
     }
 
+    /// Returns the paint with the beginning cap of the line set to the specified value.
+    pub fn with_line_cap_end(mut self, cap: LineCap) -> Self {
+        self.set_line_cap_end(cap);
+        self
+    }
+
     /// Returns the current line join for this paint.
     pub fn line_join(&self) -> LineJoin {
         self.line_join
@@ -598,6 +637,12 @@ impl Paint {
         self.line_join = join;
     }
 
+    /// Returns the paint with the line join set to the specified value.
+    pub fn with_line_join(mut self, join: LineJoin) -> Self {
+        self.set_line_join(join);
+        self
+    }
+
     pub fn set_font(&mut self, font_ids: &[FontId]) {
         self.font_ids = Default::default();
 
@@ -606,6 +651,12 @@ impl Paint {
         }
     }
 
+    /// Returns the paint with the font set to the specified value.
+    pub fn with_font(mut self, font_ids: &[FontId]) -> Self {
+        self.set_font(font_ids);
+        self
+    }
+
     /// Returns the current font size
     ///
     /// Only has effect on canvas text operations
@@ -620,6 +671,12 @@ impl Paint {
         self.font_size = size;
     }
 
+    /// Returns the paint with the font size set to the specified value.
+    pub fn with_font_size(mut self, size: f32) -> Self {
+        self.set_font_size(size);
+        self
+    }
+
     /// Returns the current letter spacing
     pub fn letter_spacing(&self) -> f32 {
         self.letter_spacing
@@ -632,6 +689,12 @@ impl Paint {
         self.letter_spacing = spacing;
     }
 
+    /// Returns the paint with the letter spacing set to the specified value.
+    pub fn with_letter_spacing(mut self, spacing: f32) -> Self {
+        self.set_letter_spacing(spacing);
+        self
+    }
+
     /// Returns the current vertical align
     pub fn text_baseline(&self) -> Baseline {
         self.text_baseline
@@ -644,6 +707,12 @@ impl Paint {
         self.text_baseline = align;
     }
 
+    /// Returns the paint with the text vertical alignment set to the specified value.
+    pub fn with_text_baseline(mut self, align: Baseline) -> Self {
+        self.set_text_baseline(align);
+        self
+    }
+
     /// Returns the current horizontal align
     pub fn text_align(&self) -> Align {
         self.text_align
@@ -656,6 +725,12 @@ impl Paint {
         self.text_align = align;
     }
 
+    /// Returns the paint with the text horizontal alignment set to the specified value.
+    pub fn with_text_align(mut self, align: Align) -> Self {
+        self.set_text_align(align);
+        self
+    }
+
     /// Retrieves the current fill rule setting for this paint
     pub fn fill_rule(&self) -> FillRule {
         self.fill_rule
@@ -668,6 +743,12 @@ impl Paint {
         self.fill_rule = rule;
     }
 
+    /// Returns the paint with the rule for filling a path set to the specified value.
+    pub fn with_fill_rule(mut self, rule: FillRule) -> Self {
+        self.set_fill_rule(rule);
+        self
+    }
+
     pub(crate) fn mul_alpha(&mut self, a: f32) {
         match &mut self.flavor {
             PaintFlavor::Color(color) => {
